/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core;

import javax.annotation.concurrent.Immutable;

import net.java.truelicense.core.auth.BasicRepository;
import net.java.truelicense.core.crypto.*;
import net.java.truelicense.core.io.Transformation;

/**
 * The root context for the management of V2 format license keys.
 *
 * @author Christian Schlichtherle
 */
@Immutable
public abstract class BasicV2LicenseManagementContext
extends BasicLicenseManagementContext {

    protected BasicV2LicenseManagementContext(String subject) { super(subject); }

    @Override public License license() { return new License(); }

    /**
     * {@inheritDoc}
     * <p>
     * The implementation in the class {@link BasicV2LicenseManagementContext}
     * returns a new {@link BasicRepository}.
     */
    @Override public final BasicRepository repository() {
        return new BasicRepository();
    }

    /**
     * {@inheritDoc}
     * <p>
     * The implementation in the class {@link BasicV2LicenseManagementContext}
     * returns a compression for V2 format license keys.
     */
    @Override public final Transformation compression() {
        return new V2Compression();
    }

    /**
     * {@inheritDoc}
     * <p>
     * The implementation in the class {@link BasicV2LicenseManagementContext}
     * returns an encryption for V2 format license keys with the given
     * parameters.
     */
    @Override public final Encryption encryption(PbeParameters pbe) {
        return new V2Encryption(pbe);
    }
}
