/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core;

import net.java.truelicense.core.auth.Authentication;
import net.java.truelicense.core.auth.KeyStoreParameters;
import net.java.truelicense.core.auth.RepositoryProvider;
import net.java.truelicense.core.codec.CodecProvider;
import net.java.truelicense.core.comp.CompressionProvider;
import net.java.truelicense.core.crypto.Encryption;
import net.java.truelicense.core.crypto.PbeParameters;
import net.java.truelicense.core.policy.PasswordPolicyProvider;
import net.java.truelicense.core.util.*;

/**
 * A root context for the life cycle management of license keys.
 * <p>
 * Applications have no need to implement this interface and should not do so
 * because it may be subject to expansion in future versions.
 *
 * @author Christian Schlichtherle
 */
public interface LicenseManagementContext
extends LicenseProvider,
        LicenseSubjectProvider,
        LicenseAuthorizationProvider,
        LicenseInitializationProvider,
        LicenseValidationProvider,
        RepositoryProvider,
        CodecProvider,
        CompressionProvider,
        PasswordPolicyProvider,
        Clock,
        ClassLoaderProvider,
        CachePeriodProvider {

    /** Returns a <em>new</em> license. */
    @Override License license();

    /**
     * Returns an authentication for the given key store parameters.
     *
     * @param ksp the key store parameters.
     */
    Authentication authentication(KeyStoreParameters ksp);

    /**
     * Returns an encryption for the given PBE parameters.
     *
     * @param pbe the PBE parameters.
     */
    Encryption encryption(PbeParameters pbe);

    /**
     * Returns a context for license vendor applications alias license key
     * tools.
     */
    LicenseVendorContext vendor();

    /**
     * Returns a context for license consumer applications.
     */
    LicenseConsumerContext consumer();
}
